# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from .types.whois_response import WhoisResponse


class RawWhoisClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_whois(
        self, *, api_key: str, whois: str, domain_name: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[WhoisResponse]:
        """
        Get WHOIS information for a domain

        Parameters
        ----------
        api_key : str

        whois : str

        domain_name : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[WhoisResponse]
        """
        _response = self._client_wrapper.httpx_client.request(
            "whois",
            method="GET",
            params={
                "apiKey": api_key,
                "whois": whois,
                "domainName": domain_name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhoisResponse,
                    parse_obj_as(
                        type_=WhoisResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(headers=dict(_response.headers), status_code=_response.status_code, body=_response.text)
        raise ApiError(headers=dict(_response.headers), status_code=_response.status_code, body=_response_json)


class AsyncRawWhoisClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_whois(
        self, *, api_key: str, whois: str, domain_name: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[WhoisResponse]:
        """
        Get WHOIS information for a domain

        Parameters
        ----------
        api_key : str

        whois : str

        domain_name : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[WhoisResponse]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "whois",
            method="GET",
            params={
                "apiKey": api_key,
                "whois": whois,
                "domainName": domain_name,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    WhoisResponse,
                    parse_obj_as(
                        type_=WhoisResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(headers=dict(_response.headers), status_code=_response.status_code, body=_response.text)
        raise ApiError(headers=dict(_response.headers), status_code=_response.status_code, body=_response_json)
